from setuptools import setup

setup(name='farhad_distributions',
      version='0.1',
      description='Gaussian distributions',
      packages=['farhad_distributions'],
      author='Farhad Kamal',
      author_email='jitubd1971@gmail.com',
      zip_safe=False)
